@@ -1,7 +1,7 @@
 
 /*
  *  agUtils.h
- *  $Id: agUtils.h,v 1.8 2002/01/31 04:07:05 bkorb Exp $
+ *  $Id: agUtils.h,v 1.9 2002/09/20 04:56:44 bkorb Exp $
  *  Utilitarian definitions for AutoGen
  */
 
@@ -32,7 +32,6 @@
 
 #include <time.h>
 #include <utime.h>
-#include <ctype.h>
 #include <sys/mman.h>
 
 #include <guile/gh.h>
@@ -47,35 +46,6 @@
 
 #define ISNAMECHAR( c ) (isalnum(c) || ((c) == '_') || ((c) == '-'))
 
-/*
- *  Procedure success codes
- *
- *  USAGE:  define procedures to return "tSuccess".  Test their results
- *          with the SUCCEEDED, FAILED and HADGLITCH macros.
- */
-#define SUCCESS  ((tSuccess) 0)
-#define FAILURE  ((tSuccess)-1)
-#define PROBLEM  ((tSuccess) 1)
-
-typedef int tSuccess;
-
-#define SUCCEEDED( p )     ((p) == SUCCESS)
-#define SUCCESSFUL( p )    SUCCEEDED( p )
-#define FAILED( p )        ((p) <  SUCCESS)
-#define HADGLITCH( p )     ((p) >  SUCCESS)
-
-#ifndef NUL
-#  define NUL '\0'
-#endif
-
-#undef STATIC
-
-#ifdef DEBUG
-#  define STATIC
-#else
-#  define STATIC static
-#endif
-
 #define STRSIZE( s )  (sizeof(s)-1)
 
 #ifdef DEFINING
