@@ -1,6 +1,6 @@
 
 /*
- *  $Id: funcCase.c,v 1.39 2002/04/21 21:43:41 bkorb Exp $
+ *  $Id: funcCase.c,v 1.40 2002/09/20 04:56:45 bkorb Exp $
  *
  *  This module implements the CASE text function.
  */
@@ -241,9 +241,9 @@ ag_scm_string_equals_p( SCM text, SCM substr )
 STATIC tSuccess
 Select_Equivalent( char* pzText, char* pzMatch )
 {
-    char*    pz  = strdup( pzText );
+    char*    pz;
     tSuccess res = SUCCESS;
-
+    AGDUPSTR( pz, pzText, "equiv chars" );
     upString( pz );
     if (strstr( pz, pzMatch ) == NULL)
         res = FAILURE;
